@@ -29,7 +29,7 @@
 */
 #define JUCE_MAJOR_VERSION      7
 #define JUCE_MINOR_VERSION      0
-#define JUCE_BUILDNUMBER        4
+#define JUCE_BUILDNUMBER        11
 
 /** Current JUCE version number.
 
@@ -67,11 +67,13 @@
 #include <queue>
 #include <set>
 #include <sstream>
+#include <string_view>
 #include <thread>
 #include <typeindex>
 #include <unordered_map>
 #include <unordered_set>
 #include <utility>
+#include <variant>
 #include <vector>
 
 //==============================================================================
@@ -90,6 +92,7 @@ JUCE_BEGIN_IGNORE_WARNINGS_MSVC (4514 4245 4100)
 
 #if JUCE_MAC || JUCE_IOS
  #include <libkern/OSAtomic.h>
+ #include <libkern/OSByteOrder.h>
  #include <xlocale.h>
  #include <signal.h>
 #endif
@@ -145,7 +148,7 @@ JUCE_END_IGNORE_WARNINGS_MSVC
   #pragma warning (disable: 1125) // (virtual override warning)
  #endif
 #elif defined (JUCE_DLL) || defined (JUCE_DLL_BUILD)
- #define JUCE_API __attribute__ ((visibility("default")))
+ #define JUCE_API __attribute__ ((visibility ("default")))
 #endif
 
 //==============================================================================
